package net.lemnik.eodsql.impl;

import java.lang.reflect.Method;

/**
 * Created on 2009/05/23
 * @author Bernd Rinn
 */
final class BatchParameterKinds {
    private final BatchParameterKind[] batchParameterKinds;
    
    private final int batchParameterCount;

    BatchParameterKinds(final Method method) {
        batchParameterKinds = getParameterKinds(method);
        batchParameterCount = countBatchParameters();
        if (batchParameterCount == 0) {
            throw new IllegalArgumentException("Batch update: no batch parameters found.");
        }
    }

    private BatchParameterKind[] getParameterKinds(Method method) {
        final Class<?>[] parameterTypes = method.getParameterTypes();
        BatchParameterKind[] kinds = new BatchParameterKind[parameterTypes.length];
        for (int i = 0; i < kinds.length; ++i) {
            kinds[i] = BatchParameterKind.getKind(parameterTypes[i]);
        }
        return kinds;
    }
    
    private int countBatchParameters() {
        int count = 0;
        for (BatchParameterKind kind : batchParameterKinds) {
            if (kind != BatchParameterKind.OTHER) {
                ++count;
            }
        }
        return count;
    }

    BatchParameterKind get(int i)
    {
        return batchParameterKinds[i];
    }

    int getSize()
    {
        return batchParameterKinds.length;
    }
    
    int getSizeBatchParameters()
    {
        return batchParameterCount;
    }

}
